@@ -338,7 +338,7 @@ def insert_sql(df, table, schema=None, placeholder="%s"):
     return insert_sql, values
 
 
-def pg_rawload(cnxn, handle, meta_df, dummy_separator="|"):
+def pg_rawload(cnxn, handle, meta_df, dummy_separator="@", table_name=None):
     """Uses psycopg2 methods to load raw data into a one-column table.
 
     Uses default schema; no support for specifying schema inside this function.
@@ -356,8 +356,11 @@ def pg_rawload(cnxn, handle, meta_df, dummy_separator="|"):
     meta_df: required
         Must be a pandas DataFrame with meta data on the file in question. I.e., returned by pyhcup.meta.get().
 
-    dummy_separator: required (default: "|")
+    dummy_separator: required (default: "@")
         Must be a character not found in the data to be loaded. The psycopg2.cursor.copy_from() method uses a tab ('\t') by default, which may result in inconsistent loads if found within the data to be loaded. The default pipe character is considered a safe choice, though it has not been exhaustively tested against all HCUP data.
+        
+    table_name: optional (default: None)
+        Table name for the load. Will be generated automatically if not provided.
 
     """
     
@@ -374,31 +377,30 @@ def pg_rawload(cnxn, handle, meta_df, dummy_separator="|"):
     now = datetime.datetime.now()
     timestamp = now.strftime('%Y%m%d%H%M%S')
     
-    raw_table_name = '%s%s_raw' % (base_filename, timestamp)
-    
+    if table_name is None:
+        table_name = '%s%s_raw' % (base_filename, timestamp)
     
     # acquire a cursor from the connection object
     cursor = cnxn.cursor()
     
-    
     # proceed to table creation
     # WARNING: this is a SQL injection vector, where a clever filename can
     # execute arbitrary SQL commands
-    raw_table_create_sql = 'CREATE TABLE IF NOT EXISTS %s (line TEXT);' % raw_table_name
+    raw_table_create_sql = 'CREATE TABLE IF NOT EXISTS %s (line TEXT);' % table_name
     cursor.execute(raw_table_create_sql)
     cnxn.commit()
     
     
     # load the data using psycopg2.cursor.copy_from() method
-    cursor.copy_from(handle, raw_table_name, sep=dummy_separator)
+    cursor.copy_from(handle, table_name, sep=dummy_separator)
     cnxn.commit()
     
-    return raw_table_name
+    return table_name
 
 
 def pg_staging(cnxn, raw_table_name, meta_df, state, year,
                pk_fields=['key', 'state', 'year'],
-               replace_sentinels=True):
+               replace_sentinels=True, table_name=None):
     """Uses PostgreSQL functions to split raw load table into columns, scrub missing data placeholders, load the results into a new table.
 
     Uses default schema; no support for specifying schema inside this function.
@@ -424,6 +426,9 @@ def pg_staging(cnxn, raw_table_name, meta_df, state, year,
     
     pk_fields: required (list or None)
         Will create a primary key and indexes using these fields. A list with length greater than 1 results in a compound primary key.
+    
+    table_name: optional (default: None)
+        Table name for the load. Will be generated automatically if not provided.
     """
     
     try:
@@ -431,13 +436,14 @@ def pg_staging(cnxn, raw_table_name, meta_df, state, year,
     except ImportError:
         raise ImportError("The pg_staging() function requires psycopg2 to be installed.")
     
-    # derive a name for this staging table
-    # prefer to have it match the raw table name, but with staging instead of raw
-    # failing that, just tack on '_staging' to the other name
-    if 'raw' in raw_table_name:
-        staging_table_name = raw_table_name.replace('raw', 'staging')
-    else:
-        staging_table_name = raw_table_name + '_staging'
+    if table_name is None:
+        # derive a name for this staging table
+        # prefer to have it match the raw table name, but with staging instead of raw
+        # failing that, just tack on '_staging' to the other name
+        if 'raw' in raw_table_name:
+            table_name = raw_table_name.replace('raw', 'staging')
+        else:
+            table_name = raw_table_name + '_staging'
     
     # acquire a cursor from the connection object
     cursor = cnxn.cursor()
@@ -478,7 +484,7 @@ def pg_staging(cnxn, raw_table_name, meta_df, state, year,
             SELECT %s
             FROM %s
         ;
-        ''' % (staging_table_name, ', '.join(col_clauses), raw_table_name)
+        ''' % (table_name, ', '.join(col_clauses), raw_table_name)
     cursor.execute(staging_table_create_sql)
     cnxn.commit()
     affected_rows = cursor.rowcount
@@ -494,20 +500,20 @@ def pg_staging(cnxn, raw_table_name, meta_df, state, year,
     if pk_fields is not None:
         if isinstance(pk_fields, list) and len(pk_fields) > 0:
             for col in pk_fields:
-                index_stmt = index_sql(col, staging_table_name)
+                index_stmt = index_sql(col, table_name)
                 cursor.execute(index_stmt)
                 cnxn.commit()
     
             pk_sql = """
                 ALTER TABLE %s ADD PRIMARY KEY(%s);
-                """ % (staging_table_name, ', '.join(pk_fields))
+                """ % (table_name, ', '.join(pk_fields))
             cursor.execute(pk_sql)
             cnxn.commit()
         
         else:
             raise TypeError("pk_fields must either be None or a non-zero length list (got %s)." % type(pk_fields))
     
-    return staging_table_name, affected_rows
+    return table_name, affected_rows
 
 
 def pg_castcoltype(archtype, length, scale=None, all_char_as_varchar=True):
@@ -610,6 +616,9 @@ def pg_wtl_shovel(cnxn, meta_df, category, tbl_source,
     if category == 'CHGS':
         wnn_base = [x for x in parser.LONG_MAPS[category]['CHARGE']
                     if x in reverse_lm.keys()]
+    elif category == 'DX':
+        wnn_base = [x for x in parser.LONG_MAPS[category]['DX']
+                    if x in reverse_lm.keys()]
     else:
         wnn_base = []
         
